--
-- PostgreSQL database dump
--

-- Started on 2011-01-08 19:54:48 CET

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

--
-- TOC entry 10 (class 2615 OID 35015)
-- Name: nekurak; Type: SCHEMA; Schema: -; Owner: nekurak
--

CREATE SCHEMA nekurak;


ALTER SCHEMA nekurak OWNER TO nekurak;

SET search_path = nekurak, pg_catalog;

--
-- TOC entry 366 (class 1247 OID 35086)
-- Dependencies: 367 10
-- Name: email; Type: DOMAIN; Schema: nekurak; Owner: nekurak
--

CREATE DOMAIN email AS character varying(255)
	CONSTRAINT email_regexp CHECK (((VALUE)::text ~ '^[_a-zA-Z0-9\\.\\-]+@[_a-zA-Z0-9\\.\\-]+\\.[a-zA-Z]{2,4}$'::text));


ALTER DOMAIN nekurak.email OWNER TO nekurak;

--
-- TOC entry 1941 (class 0 OID 0)
-- Dependencies: 366
-- Name: DOMAIN email; Type: COMMENT; Schema: nekurak; Owner: nekurak
--

COMMENT ON DOMAIN email IS 'e-mailová adresa';


--
-- TOC entry 65 (class 1255 OID 35124)
-- Dependencies: 411 10
-- Name: bezny_uzivatel(); Type: FUNCTION; Schema: nekurak; Owner: nekurak
--

CREATE FUNCTION bezny_uzivatel() RETURNS trigger
    LANGUAGE plpgsql
    AS $$BEGIN
INSERT INTO uzivatel_role 
(role, prezdivka) 
VALUES
('bezny', new.prezdivka);
RETURN new;
END;$$;


ALTER FUNCTION nekurak.bezny_uzivatel() OWNER TO nekurak;

--
-- TOC entry 1942 (class 0 OID 0)
-- Dependencies: 65
-- Name: FUNCTION bezny_uzivatel(); Type: COMMENT; Schema: nekurak; Owner: nekurak
--

COMMENT ON FUNCTION bezny_uzivatel() IS 'Každému novému uživateli dáme automaticky roli „bezny“.';


--
-- TOC entry 1610 (class 1259 OID 35223)
-- Dependencies: 10
-- Name: clanek_seq; Type: SEQUENCE; Schema: nekurak; Owner: nekurak
--

CREATE SEQUENCE clanek_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE nekurak.clanek_seq OWNER TO nekurak;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- TOC entry 1609 (class 1259 OID 35205)
-- Dependencies: 1896 10
-- Name: clanek; Type: TABLE; Schema: nekurak; Owner: nekurak; Tablespace: 
--

CREATE TABLE clanek (
    id integer DEFAULT nextval('clanek_seq'::regclass) NOT NULL,
    nadpis character varying(255) NOT NULL,
    text text
);


ALTER TABLE nekurak.clanek OWNER TO nekurak;

--
-- TOC entry 1944 (class 0 OID 0)
-- Dependencies: 1609
-- Name: TABLE clanek; Type: COMMENT; Schema: nekurak; Owner: nekurak
--

COMMENT ON TABLE clanek IS 'Článek potažmo stránka – nějaký textový obsah (XHTML).';


--
-- TOC entry 1607 (class 1259 OID 35183)
-- Dependencies: 10
-- Name: fotka_seq; Type: SEQUENCE; Schema: nekurak; Owner: nekurak
--

CREATE SEQUENCE fotka_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE nekurak.fotka_seq OWNER TO nekurak;

--
-- TOC entry 1608 (class 1259 OID 35185)
-- Dependencies: 1894 1895 10
-- Name: fotka; Type: TABLE; Schema: nekurak; Owner: nekurak; Tablespace: 
--

CREATE TABLE fotka (
    id integer DEFAULT nextval('fotka_seq'::regclass) NOT NULL,
    podnik integer NOT NULL,
    popis character varying(255),
    poradi integer DEFAULT 0 NOT NULL
);


ALTER TABLE nekurak.fotka OWNER TO nekurak;

--
-- TOC entry 1947 (class 0 OID 0)
-- Dependencies: 1608
-- Name: TABLE fotka; Type: COMMENT; Schema: nekurak; Owner: nekurak
--

COMMENT ON TABLE fotka IS 'Fotka podniku.';


--
-- TOC entry 1948 (class 0 OID 0)
-- Dependencies: 1608
-- Name: COLUMN fotka.poradi; Type: COMMENT; Schema: nekurak; Owner: nekurak
--

COMMENT ON COLUMN fotka.poradi IS 'Pořadí fotky v rámci daného podniku.';


--
-- TOC entry 1612 (class 1259 OID 35250)
-- Dependencies: 10
-- Name: hlasovani_seq; Type: SEQUENCE; Schema: nekurak; Owner: nekurak
--

CREATE SEQUENCE hlasovani_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE nekurak.hlasovani_seq OWNER TO nekurak;

--
-- TOC entry 1613 (class 1259 OID 35278)
-- Dependencies: 1897 1898 10
-- Name: hlasovani; Type: TABLE; Schema: nekurak; Owner: nekurak; Tablespace: 
--

CREATE TABLE hlasovani (
    id integer DEFAULT nextval('hlasovani_seq'::regclass) NOT NULL,
    podnik integer NOT NULL,
    hlas boolean NOT NULL,
    datum timestamp without time zone DEFAULT now() NOT NULL,
    ip_adresa character varying(255) NOT NULL
);


ALTER TABLE nekurak.hlasovani OWNER TO nekurak;

--
-- TOC entry 1951 (class 0 OID 0)
-- Dependencies: 1613
-- Name: COLUMN hlasovani.id; Type: COMMENT; Schema: nekurak; Owner: nekurak
--

COMMENT ON COLUMN hlasovani.id IS 'V této tabulce v princupu ID nepotřebujeme,
protože nebudeme adresovat konkrétní záznamy (a i kdyby, můžeme použít OID).
Ale číselné ID se nám bude hodit pro rychlejší nalezení posledního hlasu od dané IP adresy.';


--
-- TOC entry 1952 (class 0 OID 0)
-- Dependencies: 1613
-- Name: COLUMN hlasovani.hlas; Type: COMMENT; Schema: nekurak; Owner: nekurak
--

COMMENT ON COLUMN hlasovani.hlas IS 'Má být tento podnik nekuřácký?
true = nekuřácký
false = kouření povoleno';


--
-- TOC entry 1616 (class 1259 OID 35396)
-- Dependencies: 10
-- Name: kategorie_seq; Type: SEQUENCE; Schema: nekurak; Owner: nekurak
--

CREATE SEQUENCE kategorie_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE nekurak.kategorie_seq OWNER TO nekurak;

--
-- TOC entry 1617 (class 1259 OID 35398)
-- Dependencies: 1901 10
-- Name: kategorie; Type: TABLE; Schema: nekurak; Owner: nekurak; Tablespace: 
--

CREATE TABLE kategorie (
    id integer DEFAULT nextval('kategorie_seq'::regclass) NOT NULL,
    nazev character varying(32) NOT NULL,
    popis character varying(255)
);


ALTER TABLE nekurak.kategorie OWNER TO nekurak;

--
-- TOC entry 1955 (class 0 OID 0)
-- Dependencies: 1617
-- Name: TABLE kategorie; Type: COMMENT; Schema: nekurak; Owner: nekurak
--

COMMENT ON TABLE kategorie IS 'Kategorie podniku';


--
-- TOC entry 1614 (class 1259 OID 35333)
-- Dependencies: 10
-- Name: komentar_seq; Type: SEQUENCE; Schema: nekurak; Owner: nekurak
--

CREATE SEQUENCE komentar_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE nekurak.komentar_seq OWNER TO nekurak;

--
-- TOC entry 1615 (class 1259 OID 35376)
-- Dependencies: 1899 1900 10
-- Name: komentar; Type: TABLE; Schema: nekurak; Owner: nekurak; Tablespace: 
--

CREATE TABLE komentar (
    id integer DEFAULT nextval('komentar_seq'::regclass) NOT NULL,
    podnik integer NOT NULL,
    uzivatel character varying(64) NOT NULL,
    datum timestamp with time zone DEFAULT now() NOT NULL,
    nadpis character varying(255),
    komentar text NOT NULL
);


ALTER TABLE nekurak.komentar OWNER TO nekurak;

--
-- TOC entry 1958 (class 0 OID 0)
-- Dependencies: 1615
-- Name: TABLE komentar; Type: COMMENT; Schema: nekurak; Owner: nekurak
--

COMMENT ON TABLE komentar IS 'Komentář k podniku';


--
-- TOC entry 1959 (class 0 OID 0)
-- Dependencies: 1615
-- Name: COLUMN komentar.nadpis; Type: COMMENT; Schema: nekurak; Owner: nekurak
--

COMMENT ON COLUMN komentar.nadpis IS 'vždy jen prostý text';


--
-- TOC entry 1960 (class 0 OID 0)
-- Dependencies: 1615
-- Name: COLUMN komentar.komentar; Type: COMMENT; Schema: nekurak; Owner: nekurak
--

COMMENT ON COLUMN komentar.komentar IS 'Vlastní komentář. Vždy jen XHTML – převádíme na něj jak prostý text, tak Texy nebo cokoli jiného.
Jedná se o kus validního XML – má kořenový element <div/>';


--
-- TOC entry 1601 (class 1259 OID 35019)
-- Dependencies: 10
-- Name: podnik_seq; Type: SEQUENCE; Schema: nekurak; Owner: nekurak
--

CREATE SEQUENCE podnik_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE nekurak.podnik_seq OWNER TO nekurak;

--
-- TOC entry 1602 (class 1259 OID 35049)
-- Dependencies: 1890 1891 10
-- Name: podnik; Type: TABLE; Schema: nekurak; Owner: nekurak; Tablespace: 
--

CREATE TABLE podnik (
    id integer DEFAULT nextval('podnik_seq'::regclass) NOT NULL,
    nazev character varying(255) NOT NULL,
    popis character varying(255),
    url character varying(255),
    datum timestamp with time zone DEFAULT now(),
    ulice character varying(64),
    cislo_popisne integer,
    mesto character varying(64),
    spravce character varying(64),
    sirka double precision,
    delka double precision
);


ALTER TABLE nekurak.podnik OWNER TO nekurak;

--
-- TOC entry 1963 (class 0 OID 0)
-- Dependencies: 1602
-- Name: COLUMN podnik.spravce; Type: COMMENT; Schema: nekurak; Owner: nekurak
--

COMMENT ON COLUMN podnik.spravce IS 'Přezdívka uživatele, který je správcem tohoto podniku (zadal ho do systému nebo správcovství později dostal)';


--
-- TOC entry 1618 (class 1259 OID 35404)
-- Dependencies: 10
-- Name: podnik_kategorie; Type: TABLE; Schema: nekurak; Owner: nekurak; Tablespace: 
--

CREATE TABLE podnik_kategorie (
    podnik integer NOT NULL,
    kategorie integer NOT NULL
);


ALTER TABLE nekurak.podnik_kategorie OWNER TO nekurak;

--
-- TOC entry 1605 (class 1259 OID 35101)
-- Dependencies: 10
-- Name: role; Type: TABLE; Schema: nekurak; Owner: nekurak; Tablespace: 
--

CREATE TABLE role (
    kod character varying(16) NOT NULL,
    popis character varying(255)
);


ALTER TABLE nekurak.role OWNER TO nekurak;

--
-- TOC entry 1966 (class 0 OID 0)
-- Dependencies: 1605
-- Name: TABLE role; Type: COMMENT; Schema: nekurak; Owner: nekurak
--

COMMENT ON TABLE role IS 'Role (skupiny) uživatelů ~ oprávnění';


--
-- TOC entry 1603 (class 1259 OID 35080)
-- Dependencies: 10
-- Name: uzivatel_seq; Type: SEQUENCE; Schema: nekurak; Owner: nekurak
--

CREATE SEQUENCE uzivatel_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE nekurak.uzivatel_seq OWNER TO nekurak;

--
-- TOC entry 1604 (class 1259 OID 35091)
-- Dependencies: 1892 1893 10
-- Name: uzivatel; Type: TABLE; Schema: nekurak; Owner: nekurak; Tablespace: 
--

CREATE TABLE uzivatel (
    id integer DEFAULT nextval('uzivatel_seq'::regclass) NOT NULL,
    prezdivka character varying(64) NOT NULL,
    heslo character varying(512) NOT NULL,
    jmeno character varying(64),
    prijmeni character varying(64),
    email character varying(255),
    datum timestamp with time zone DEFAULT now() NOT NULL
);


ALTER TABLE nekurak.uzivatel OWNER TO nekurak;

--
-- TOC entry 1969 (class 0 OID 0)
-- Dependencies: 1604
-- Name: COLUMN uzivatel.prezdivka; Type: COMMENT; Schema: nekurak; Owner: nekurak
--

COMMENT ON COLUMN uzivatel.prezdivka IS 'Uživatelské jméno';


--
-- TOC entry 1606 (class 1259 OID 35106)
-- Dependencies: 10
-- Name: uzivatel_role; Type: TABLE; Schema: nekurak; Owner: nekurak; Tablespace: 
--

CREATE TABLE uzivatel_role (
    role character varying(16) NOT NULL,
    prezdivka character varying(64) NOT NULL
);


ALTER TABLE nekurak.uzivatel_role OWNER TO nekurak;

--
-- TOC entry 1971 (class 0 OID 0)
-- Dependencies: 1606
-- Name: TABLE uzivatel_role; Type: COMMENT; Schema: nekurak; Owner: nekurak
--

COMMENT ON TABLE uzivatel_role IS 'Přiřazení uživatelských rolí (skupin).';


--
-- TOC entry 1917 (class 2606 OID 35227)
-- Dependencies: 1609 1609
-- Name: clanek_pk; Type: CONSTRAINT; Schema: nekurak; Owner: nekurak; Tablespace: 
--

ALTER TABLE ONLY clanek
    ADD CONSTRAINT clanek_pk PRIMARY KEY (id);


--
-- TOC entry 1913 (class 2606 OID 35190)
-- Dependencies: 1608 1608
-- Name: fotka_pk; Type: CONSTRAINT; Schema: nekurak; Owner: nekurak; Tablespace: 
--

ALTER TABLE ONLY fotka
    ADD CONSTRAINT fotka_pk PRIMARY KEY (id);


--
-- TOC entry 1915 (class 2606 OID 35204)
-- Dependencies: 1608 1608 1608
-- Name: fotka_poradi_uq; Type: CONSTRAINT; Schema: nekurak; Owner: nekurak; Tablespace: 
--

ALTER TABLE ONLY fotka
    ADD CONSTRAINT fotka_poradi_uq UNIQUE (popis, poradi);


--
-- TOC entry 1920 (class 2606 OID 35284)
-- Dependencies: 1613 1613
-- Name: hlasovani_pk; Type: CONSTRAINT; Schema: nekurak; Owner: nekurak; Tablespace: 
--

ALTER TABLE ONLY hlasovani
    ADD CONSTRAINT hlasovani_pk PRIMARY KEY (id);


--
-- TOC entry 1925 (class 2606 OID 35403)
-- Dependencies: 1617 1617
-- Name: kategorie_pk; Type: CONSTRAINT; Schema: nekurak; Owner: nekurak; Tablespace: 
--

ALTER TABLE ONLY kategorie
    ADD CONSTRAINT kategorie_pk PRIMARY KEY (id);


--
-- TOC entry 1923 (class 2606 OID 35385)
-- Dependencies: 1615 1615
-- Name: komentar_pk; Type: CONSTRAINT; Schema: nekurak; Owner: nekurak; Tablespace: 
--

ALTER TABLE ONLY komentar
    ADD CONSTRAINT komentar_pk PRIMARY KEY (id);


--
-- TOC entry 1927 (class 2606 OID 35408)
-- Dependencies: 1618 1618 1618
-- Name: podnik_kategorie_pk; Type: CONSTRAINT; Schema: nekurak; Owner: nekurak; Tablespace: 
--

ALTER TABLE ONLY podnik_kategorie
    ADD CONSTRAINT podnik_kategorie_pk PRIMARY KEY (podnik, kategorie);


--
-- TOC entry 1903 (class 2606 OID 35058)
-- Dependencies: 1602 1602
-- Name: podnik_pk; Type: CONSTRAINT; Schema: nekurak; Owner: nekurak; Tablespace: 
--

ALTER TABLE ONLY podnik
    ADD CONSTRAINT podnik_pk PRIMARY KEY (id);


--
-- TOC entry 1909 (class 2606 OID 35105)
-- Dependencies: 1605 1605
-- Name: skupina_pk; Type: CONSTRAINT; Schema: nekurak; Owner: nekurak; Tablespace: 
--

ALTER TABLE ONLY role
    ADD CONSTRAINT skupina_pk PRIMARY KEY (kod);


--
-- TOC entry 1905 (class 2606 OID 35098)
-- Dependencies: 1604 1604
-- Name: uzivatel_pk; Type: CONSTRAINT; Schema: nekurak; Owner: nekurak; Tablespace: 
--

ALTER TABLE ONLY uzivatel
    ADD CONSTRAINT uzivatel_pk PRIMARY KEY (id);


--
-- TOC entry 1907 (class 2606 OID 35100)
-- Dependencies: 1604 1604
-- Name: uzivatel_prezdivka_uq; Type: CONSTRAINT; Schema: nekurak; Owner: nekurak; Tablespace: 
--

ALTER TABLE ONLY uzivatel
    ADD CONSTRAINT uzivatel_prezdivka_uq UNIQUE (prezdivka);


--
-- TOC entry 1911 (class 2606 OID 35137)
-- Dependencies: 1606 1606 1606
-- Name: uzivatel_role_pk; Type: CONSTRAINT; Schema: nekurak; Owner: nekurak; Tablespace: 
--

ALTER TABLE ONLY uzivatel_role
    ADD CONSTRAINT uzivatel_role_pk PRIMARY KEY (role, prezdivka);


--
-- TOC entry 1918 (class 1259 OID 35291)
-- Dependencies: 1613
-- Name: hlasovani_ip_idx; Type: INDEX; Schema: nekurak; Owner: nekurak; Tablespace: 
--

CREATE INDEX hlasovani_ip_idx ON hlasovani USING btree (ip_adresa);


--
-- TOC entry 1921 (class 1259 OID 35309)
-- Dependencies: 1613
-- Name: hlsovani_datum_idx; Type: INDEX; Schema: nekurak; Owner: nekurak; Tablespace: 
--

CREATE INDEX hlsovani_datum_idx ON hlasovani USING btree (date(datum));


--
-- TOC entry 1937 (class 2620 OID 35125)
-- Dependencies: 1604 65
-- Name: uzivatel_insert; Type: TRIGGER; Schema: nekurak; Owner: nekurak
--

CREATE TRIGGER uzivatel_insert
    AFTER INSERT ON uzivatel
    FOR EACH ROW
    EXECUTE PROCEDURE bezny_uzivatel();


--
-- TOC entry 1931 (class 2606 OID 35191)
-- Dependencies: 1608 1602 1902
-- Name: fotka_podnik_fk; Type: FK CONSTRAINT; Schema: nekurak; Owner: nekurak
--

ALTER TABLE ONLY fotka
    ADD CONSTRAINT fotka_podnik_fk FOREIGN KEY (podnik) REFERENCES podnik(id) ON DELETE CASCADE;


--
-- TOC entry 1932 (class 2606 OID 35285)
-- Dependencies: 1602 1902 1613
-- Name: hlasovani_podnik_fk; Type: FK CONSTRAINT; Schema: nekurak; Owner: nekurak
--

ALTER TABLE ONLY hlasovani
    ADD CONSTRAINT hlasovani_podnik_fk FOREIGN KEY (podnik) REFERENCES podnik(id) ON DELETE CASCADE;


--
-- TOC entry 1933 (class 2606 OID 35386)
-- Dependencies: 1615 1602 1902
-- Name: komentar_podnik_fk; Type: FK CONSTRAINT; Schema: nekurak; Owner: nekurak
--

ALTER TABLE ONLY komentar
    ADD CONSTRAINT komentar_podnik_fk FOREIGN KEY (podnik) REFERENCES podnik(id);


--
-- TOC entry 1934 (class 2606 OID 35391)
-- Dependencies: 1615 1906 1604
-- Name: komentar_uzivatel_fk; Type: FK CONSTRAINT; Schema: nekurak; Owner: nekurak
--

ALTER TABLE ONLY komentar
    ADD CONSTRAINT komentar_uzivatel_fk FOREIGN KEY (uzivatel) REFERENCES uzivatel(prezdivka);


--
-- TOC entry 1936 (class 2606 OID 35414)
-- Dependencies: 1924 1618 1617
-- Name: podnik_kategorie_kategorie_fk; Type: FK CONSTRAINT; Schema: nekurak; Owner: nekurak
--

ALTER TABLE ONLY podnik_kategorie
    ADD CONSTRAINT podnik_kategorie_kategorie_fk FOREIGN KEY (kategorie) REFERENCES kategorie(id) ON DELETE CASCADE;


--
-- TOC entry 1935 (class 2606 OID 35409)
-- Dependencies: 1618 1902 1602
-- Name: podnik_kategorie_podnik_fk; Type: FK CONSTRAINT; Schema: nekurak; Owner: nekurak
--

ALTER TABLE ONLY podnik_kategorie
    ADD CONSTRAINT podnik_kategorie_podnik_fk FOREIGN KEY (podnik) REFERENCES podnik(id) ON DELETE CASCADE;


--
-- TOC entry 1928 (class 2606 OID 35178)
-- Dependencies: 1602 1604 1906
-- Name: podnik_uzivatel_fk; Type: FK CONSTRAINT; Schema: nekurak; Owner: nekurak
--

ALTER TABLE ONLY podnik
    ADD CONSTRAINT podnik_uzivatel_fk FOREIGN KEY (spravce) REFERENCES uzivatel(prezdivka) ON DELETE SET NULL;


--
-- TOC entry 1929 (class 2606 OID 35138)
-- Dependencies: 1605 1908 1606
-- Name: uzivatel_role_role_fk; Type: FK CONSTRAINT; Schema: nekurak; Owner: nekurak
--

ALTER TABLE ONLY uzivatel_role
    ADD CONSTRAINT uzivatel_role_role_fk FOREIGN KEY (role) REFERENCES role(kod) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- TOC entry 1930 (class 2606 OID 35143)
-- Dependencies: 1604 1606 1906
-- Name: uzivatel_role_uzivatel_fk; Type: FK CONSTRAINT; Schema: nekurak; Owner: nekurak
--

ALTER TABLE ONLY uzivatel_role
    ADD CONSTRAINT uzivatel_role_uzivatel_fk FOREIGN KEY (prezdivka) REFERENCES uzivatel(prezdivka) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- TOC entry 1940 (class 0 OID 0)
-- Dependencies: 10
-- Name: nekurak; Type: ACL; Schema: -; Owner: nekurak
--

REVOKE ALL ON SCHEMA nekurak FROM PUBLIC;
REVOKE ALL ON SCHEMA nekurak FROM nekurak;
GRANT ALL ON SCHEMA nekurak TO nekurak;
GRANT USAGE ON SCHEMA nekurak TO nekurak_web;


--
-- TOC entry 1943 (class 0 OID 0)
-- Dependencies: 1610
-- Name: clanek_seq; Type: ACL; Schema: nekurak; Owner: nekurak
--

REVOKE ALL ON SEQUENCE clanek_seq FROM PUBLIC;
REVOKE ALL ON SEQUENCE clanek_seq FROM nekurak;
GRANT ALL ON SEQUENCE clanek_seq TO nekurak;
GRANT USAGE ON SEQUENCE clanek_seq TO nekurak_web;


--
-- TOC entry 1945 (class 0 OID 0)
-- Dependencies: 1609
-- Name: clanek; Type: ACL; Schema: nekurak; Owner: nekurak
--

REVOKE ALL ON TABLE clanek FROM PUBLIC;
REVOKE ALL ON TABLE clanek FROM nekurak;
GRANT ALL ON TABLE clanek TO nekurak;
GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE clanek TO nekurak_web;


--
-- TOC entry 1946 (class 0 OID 0)
-- Dependencies: 1607
-- Name: fotka_seq; Type: ACL; Schema: nekurak; Owner: nekurak
--

REVOKE ALL ON SEQUENCE fotka_seq FROM PUBLIC;
REVOKE ALL ON SEQUENCE fotka_seq FROM nekurak;
GRANT ALL ON SEQUENCE fotka_seq TO nekurak;
GRANT USAGE ON SEQUENCE fotka_seq TO nekurak_web;


--
-- TOC entry 1949 (class 0 OID 0)
-- Dependencies: 1608
-- Name: fotka; Type: ACL; Schema: nekurak; Owner: nekurak
--

REVOKE ALL ON TABLE fotka FROM PUBLIC;
REVOKE ALL ON TABLE fotka FROM nekurak;
GRANT ALL ON TABLE fotka TO nekurak;
GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE fotka TO nekurak_web;


--
-- TOC entry 1950 (class 0 OID 0)
-- Dependencies: 1612
-- Name: hlasovani_seq; Type: ACL; Schema: nekurak; Owner: nekurak
--

REVOKE ALL ON SEQUENCE hlasovani_seq FROM PUBLIC;
REVOKE ALL ON SEQUENCE hlasovani_seq FROM nekurak;
GRANT ALL ON SEQUENCE hlasovani_seq TO nekurak;
GRANT USAGE ON SEQUENCE hlasovani_seq TO nekurak_web;


--
-- TOC entry 1953 (class 0 OID 0)
-- Dependencies: 1613
-- Name: hlasovani; Type: ACL; Schema: nekurak; Owner: nekurak
--

REVOKE ALL ON TABLE hlasovani FROM PUBLIC;
REVOKE ALL ON TABLE hlasovani FROM nekurak;
GRANT ALL ON TABLE hlasovani TO nekurak;
GRANT SELECT,INSERT ON TABLE hlasovani TO nekurak_web;


--
-- TOC entry 1954 (class 0 OID 0)
-- Dependencies: 1616
-- Name: kategorie_seq; Type: ACL; Schema: nekurak; Owner: nekurak
--

REVOKE ALL ON SEQUENCE kategorie_seq FROM PUBLIC;
REVOKE ALL ON SEQUENCE kategorie_seq FROM nekurak;
GRANT ALL ON SEQUENCE kategorie_seq TO nekurak;
GRANT USAGE ON SEQUENCE kategorie_seq TO nekurak_web;


--
-- TOC entry 1956 (class 0 OID 0)
-- Dependencies: 1617
-- Name: kategorie; Type: ACL; Schema: nekurak; Owner: nekurak
--

REVOKE ALL ON TABLE kategorie FROM PUBLIC;
REVOKE ALL ON TABLE kategorie FROM nekurak;
GRANT ALL ON TABLE kategorie TO nekurak;
GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE kategorie TO nekurak_web;


--
-- TOC entry 1957 (class 0 OID 0)
-- Dependencies: 1614
-- Name: komentar_seq; Type: ACL; Schema: nekurak; Owner: nekurak
--

REVOKE ALL ON SEQUENCE komentar_seq FROM PUBLIC;
REVOKE ALL ON SEQUENCE komentar_seq FROM nekurak;
GRANT ALL ON SEQUENCE komentar_seq TO nekurak;
GRANT USAGE ON SEQUENCE komentar_seq TO nekurak_web;


--
-- TOC entry 1961 (class 0 OID 0)
-- Dependencies: 1615
-- Name: komentar; Type: ACL; Schema: nekurak; Owner: nekurak
--

REVOKE ALL ON TABLE komentar FROM PUBLIC;
REVOKE ALL ON TABLE komentar FROM nekurak;
GRANT ALL ON TABLE komentar TO nekurak;
GRANT SELECT,INSERT ON TABLE komentar TO nekurak_web;


--
-- TOC entry 1962 (class 0 OID 0)
-- Dependencies: 1601
-- Name: podnik_seq; Type: ACL; Schema: nekurak; Owner: nekurak
--

REVOKE ALL ON SEQUENCE podnik_seq FROM PUBLIC;
REVOKE ALL ON SEQUENCE podnik_seq FROM nekurak;
GRANT ALL ON SEQUENCE podnik_seq TO nekurak;
GRANT USAGE ON SEQUENCE podnik_seq TO nekurak_web;


--
-- TOC entry 1964 (class 0 OID 0)
-- Dependencies: 1602
-- Name: podnik; Type: ACL; Schema: nekurak; Owner: nekurak
--

REVOKE ALL ON TABLE podnik FROM PUBLIC;
REVOKE ALL ON TABLE podnik FROM nekurak;
GRANT ALL ON TABLE podnik TO nekurak;
GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE podnik TO nekurak_web;


--
-- TOC entry 1965 (class 0 OID 0)
-- Dependencies: 1618
-- Name: podnik_kategorie; Type: ACL; Schema: nekurak; Owner: nekurak
--

REVOKE ALL ON TABLE podnik_kategorie FROM PUBLIC;
REVOKE ALL ON TABLE podnik_kategorie FROM nekurak;
GRANT ALL ON TABLE podnik_kategorie TO nekurak;
GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE podnik_kategorie TO nekurak_web;


--
-- TOC entry 1967 (class 0 OID 0)
-- Dependencies: 1605
-- Name: role; Type: ACL; Schema: nekurak; Owner: nekurak
--

REVOKE ALL ON TABLE role FROM PUBLIC;
REVOKE ALL ON TABLE role FROM nekurak;
GRANT ALL ON TABLE role TO nekurak;
GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE role TO nekurak_web;


--
-- TOC entry 1968 (class 0 OID 0)
-- Dependencies: 1603
-- Name: uzivatel_seq; Type: ACL; Schema: nekurak; Owner: nekurak
--

REVOKE ALL ON SEQUENCE uzivatel_seq FROM PUBLIC;
REVOKE ALL ON SEQUENCE uzivatel_seq FROM nekurak;
GRANT ALL ON SEQUENCE uzivatel_seq TO nekurak;
GRANT USAGE ON SEQUENCE uzivatel_seq TO nekurak_web;


--
-- TOC entry 1970 (class 0 OID 0)
-- Dependencies: 1604
-- Name: uzivatel; Type: ACL; Schema: nekurak; Owner: nekurak
--

REVOKE ALL ON TABLE uzivatel FROM PUBLIC;
REVOKE ALL ON TABLE uzivatel FROM nekurak;
GRANT ALL ON TABLE uzivatel TO nekurak;
GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE uzivatel TO nekurak_web;


--
-- TOC entry 1972 (class 0 OID 0)
-- Dependencies: 1606
-- Name: uzivatel_role; Type: ACL; Schema: nekurak; Owner: nekurak
--

REVOKE ALL ON TABLE uzivatel_role FROM PUBLIC;
REVOKE ALL ON TABLE uzivatel_role FROM nekurak;
GRANT ALL ON TABLE uzivatel_role TO nekurak;
GRANT SELECT,INSERT,DELETE,UPDATE ON TABLE uzivatel_role TO nekurak_web;


-- Completed on 2011-01-08 19:54:50 CET

--
-- PostgreSQL database dump complete
--

